@@ -143,12 +143,7 @@ void Application::registerQmlTypes()
     qRegisterMetaType<PlayListModel *>();
     qRegisterMetaType<PlayListItem *>();
     qRegisterMetaType<TracksModel *>();
-
-#if KCONFIG_VERSION >= QT_VERSION_CHECK(5, 89, 0)
-    qRegisterMetaType<KFileMetaData::PropertyMap>("KFileMetaData::PropertyMultiMap");
-#else
-    qRegisterMetaType<KFileMetaData::PropertyMap>("KFileMetaData::PropertyMap");
-#endif
+    qRegisterMetaType<KFileMetaData::PropertyMultiMap>("KFileMetaData::PropertyMultiMap");
     // models
     qmlRegisterType<SubtitlesFoldersModel>("org.kde.haruna.models", 1, 0, "SubtitlesFoldersModel");
     qmlRegisterType<ActionsModel>("org.kde.haruna.models", 1, 0, "ActionsModel");
@@ -392,8 +387,12 @@ void Application::raiseWindow()
     // todo: replace deprecated methods
     QWindow *window = qobject_cast<QWindow *>(m_rootObject);
     if (window) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         KStartupInfo::setNewStartupId(window, KStartupInfo::startupId());
         KWindowSystem::activateWindow(window->winId());
+#else
+        KWindowSystem::activateWindow(window);
+#endif
     }
 }
 
