@@ -35,11 +35,7 @@ PlayListModel::PlayListModel(QObject *parent)
 {
     connect(this, &PlayListModel::itemAdded, Worker::instance(), &Worker::getMetaData);
 
-#if KCONFIG_VERSION >= QT_VERSION_CHECK(5, 89, 0)
     connect(Worker::instance(), &Worker::metaDataReady, this, [=](int i, KFileMetaData::PropertyMultiMap metaData) {
-#else
-    connect(Worker::instance(), &Worker::metaDataReady, this, [=](int i, KFileMetaData::PropertyMap metaData) {
-#endif
         auto duration = metaData.value(KFileMetaData::Property::Duration).toInt();
         auto title = metaData.value(KFileMetaData::Property::Title).toString();
 
@@ -445,7 +441,7 @@ void PlayListProxyModel::sortItems(Sort sortMode)
 int PlayListProxyModel::getPlayingItem()
 {
     auto model = qobject_cast<PlayListModel *>(sourceModel());
-    return mapFromSource(index(model->getPlayingItem(), 0)).row();
+    return mapFromSource(model->index(model->getPlayingItem(), 0)).row();
 }
 
 void PlayListProxyModel::setPlayingItem(int i)
