@@ -34,15 +34,17 @@ public:
     QHash<int, QByteArray> roleNames() const override;
     Q_INVOKABLE void addUrl(const QString &path, const QString &name = QString());
     Q_INVOKABLE void clear();
+    Q_INVOKABLE void deleteEntries();
     Q_INVOKABLE void populate();
 
     int maxRecentFiles() const;
     void setMaxRecentFiles(int _maxRecentFiles);
 
 private:
+    void saveEntries();
     QList<RecentFile> m_urls;
     KConfigGroup m_recentFilesConfigGroup;
-    int m_maxRecentFiles {10};
+    int m_maxRecentFiles{10};
 };
 
 #endif // RECENTFILESMODEL_H
