@@ -16,6 +16,7 @@
 #include <QStandardPaths>
 #include <QTimer>
 #include <QtGlobal>
+#include <playlistsettings.h>
 
 #include <KLocalizedString>
 #include <KShell>
@@ -70,7 +71,7 @@ MpvItem::MpvItem(QQuickItem *parent)
     timer->start();
 
     connect(timer, &QTimer::timeout, this, [=]() {
-        if (duration() > 0) {
+        if (duration() > 0 && !pause()) {
             if (position() < duration() - 10) {
                 saveTimePosition();
             } else {
@@ -79,6 +80,14 @@ MpvItem::MpvItem(QQuickItem *parent)
         }
     });
 
+    connect(QApplication::instance(), &QApplication::aboutToQuit, this, [=]() {
+        if (position() < duration() - 10) {
+            saveTimePosition();
+        } else {
+            resetTimePosition();
+        }
+    });
+
     // run user commands
     KSharedConfig::Ptr m_customPropsConfig;
     QString ccConfig = Global::instance()->appConfigFilePath(Global::ConfigFile::CustomCommands);
@@ -153,7 +162,35 @@ void MpvItem::setupConnections()
 
     connect(m_mpvController, &MpvController::endFile,
             this, &MpvItem::endFile, Qt::QueuedConnection);
-    // clang-format on
+
+    connect(this, &MpvItem::fileLoaded, this, [=]() {
+        if (!getProperty("vid").toBool()) {
+            command(QStringList{QStringLiteral("video-add"), VideoSettings::defaultCover()});
+        }
+
+        setWatchLaterPosition(loadTimePosition());
+
+        if (m_playlistModel->rowCount() <= 1 && PlaylistSettings::repeat()) {
+            setProperty(QStringLiteral("loop-file"), QStringLiteral("inf"));
+        }
+
+        setProperty(QStringLiteral("ab-loop-a"), QStringLiteral("no"));
+        setProperty(QStringLiteral("ab-loop-b"), QStringLiteral("no"));
+
+        // this is only run when reloading the last file in the playlist
+        // due to the playlist repeat setting being turned off
+        if (isFileReloaded()) {
+            setPause(true);
+            setPosition(0);
+            setIsFileReloaded(false);
+            return;
+        }
+
+        if (PlaybackSettings::seekToLastPosition()) {
+            setPause(!PlaybackSettings::playOnResume() && watchLaterPosition() > 0);
+            setPosition(watchLaterPosition());
+        }
+    });
 
     connect(this, &MpvItem::positionChanged, this, [this]() {
         int pos = m_position;
@@ -217,6 +254,7 @@ void MpvItem::setupConnections()
 #endif
 
     connect(this, &MpvItem::syncConfigValue, Worker::instance(), &Worker::syncConfigValue, Qt::QueuedConnection);
+    // clang-format on
 }
 
 PlayListModel *MpvItem::playlistModel()
@@ -239,6 +277,20 @@ void MpvItem::setPlaylistProxyModel(PlayListProxyModel *model)
     m_playlistProxyModel = model;
 }
 
+bool MpvItem::isFileReloaded() const
+{
+    return m_isFileReloaded;
+}
+
+void MpvItem::setIsFileReloaded(bool _isFileReloaded)
+{
+    if (m_isFileReloaded == _isFileReloaded) {
+        return;
+    }
+    m_isFileReloaded = _isFileReloaded;
+    emit isFileReloadedChanged();
+}
+
 QString MpvItem::mediaTitle()
 {
     return getCachedPropertyValue(QStringLiteral("media-title")).toString();
@@ -257,6 +309,20 @@ void MpvItem::setPosition(double value)
     Q_EMIT setMpvProperty(QStringLiteral("time-pos"), value);
 }
 
+double MpvItem::watchLaterPosition() const
+{
+    return m_watchLaterPosition;
+}
+
+void MpvItem::setWatchLaterPosition(double _watchLaterPosition)
+{
+    if (qFuzzyCompare(m_watchLaterPosition + 1, _watchLaterPosition + 1)) {
+        return;
+    }
+    m_watchLaterPosition = _watchLaterPosition;
+    emit watchLaterPositionChanged();
+}
+
 double MpvItem::remaining()
 {
     return getCachedPropertyValue(QStringLiteral("time-remaining")).toDouble();
